#!/usr/bin/python

from __future__ import print_function

import glob
import os.path
import sys

try:
    from urllib.request import urlopen
except ImportError:
    from urllib import urlopen

print(sys.version_info)
PYTHON_VERSION = "{}.{}".format(sys.version_info.major, sys.version_info.minor)

for p in glob.glob("build/lib.*-" + PYTHON_VERSION):
    print("Inserting build path {}".format(p))
    sys.path.insert(0, p)

print((sys.path))

import mad

print(mad.__file__)


def play(u):
    mf = mad.MadFile(u)

    if mf.layer() == mad.LAYER_I:
        print("MPEG Layer I")
    elif mf.layer() == mad.LAYER_II:
        print("MPEG Layer II")
    elif mf.layer() == mad.LAYER_III:
        print("MPEG Layer III")
    else:
        print("unexpected layer value")

    if mf.mode() == mad.MODE_SINGLE_CHANNEL:
        print("single channel")
    elif mf.mode() == mad.MODE_DUAL_CHANNEL:
        print("dual channel")
    elif mf.mode() == mad.MODE_JOINT_STEREO:
        print("joint (MS/intensity) stereo")
    elif mf.mode() == mad.MODE_STEREO:
        print("normal L/R stereo")
    else:
        print("unexpected mode value")

    if mf.emphasis() == mad.EMPHASIS_NONE:
        print("no emphasis")
    elif mf.emphasis() == mad.EMPHASIS_50_15_US:
        print("50/15us emphasis")
    elif mf.emphasis() == mad.EMPHASIS_CCITT_J_17:
        print("CCITT J.17 emphasis")
    else:
        print("unexpected emphasis value")

    print(("bitrate %lu bps" % mf.bitrate()))
    print(("samplerate %d Hz" % mf.samplerate()))
    sys.stdout.flush()
    #millis = mf.total_time()
    #secs = millis / 1000
    # print "total time %d ms (%dm%2ds)" % (millis, secs / 60, secs % 60)

    #dev = ao.AudioDevice(0, rate=mf.samplerate())
    while 1:
        buffy = mf.read()
        if buffy is None:
            break
        #dev.play(buffy, len(buffy))
        # print "current time: %d ms" % mf.current_time()

if __name__ == "__main__":
    print(("pymad version %s" % mad.__version__))
    for filename in sys.argv[1:]:
        if os.path.exists(filename):
            filename = "file://" + filename
        u = urlopen(filename)
        if u:
            # if os.path.exists(file):
            print(("playing %s" % filename))
            play(u)



#! /usr/bin/env python

import glob
import os.path
import socket
import sys

try:
    from urllib.parse import urlparse
except ImportError:
    from urlparse import urlparse

import ao

for p in glob.glob('build/lib.*'):
    sys.path.insert(0, p)

import mad


def madradio(url):
    scheme, netloc, path, params, query, fragment = urlparse(url)
    try:
        host, port = netloc.split(':')
    except ValueError:
        host, port = netloc, 80
    if not path:
        path = '/'
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    sock.connect((host, int(port)))
    sock.send('GET %s HTTP/1.0\r\n\r\n' % path)
    reply = sock.recv(1500)
    # print repr(reply)
    file = sock.makefile()
    mf = mad.MadFile(file)
    print(('bitrate %lu bps' % mf.bitrate()))
    print(('samplerate %d Hz' % mf.samplerate()))
    dev = ao.AudioDevice(0, rate=mf.samplerate())
    while True:
        buffy = mf.read()
        if buffy is None:
            break
        dev.play(buffy, len(buffy))

if __name__ == '__main__':
    import sys
    try:
        url = sys.argv[1]
    except IndexError:
        # url = 'http://62.67.195.6:8000' # lounge-radio.com
        # url = 'http://63.241.4.18:8069' # xtcradio.com
        url = 'http://mp2.somafm.com:2040'  # somafm
    madradio(url)



#!/usr/bin/env python

from __future__ import print_function

import os
import sys


def msg_checking(msg):
  print('Checking {0}... '.format(msg), end='')


def execute(cmd, display=0):
  if display:
    print(cmd)
  return os.system(cmd)


def run_test(inp, flags=''):
  try:
    tmp = open('_temp.c', 'w')
    tmp.write(inp)
    tmp.close()
    compile_cmd = '%s -o _temp _temp.c %s' % (os.environ.get('CC', 'cc'),
                                              flags)
    if not execute(compile_cmd):
      execute('./_temp')
  finally:
    execute('rm -f _temp.c _temp')

MAD_TEST_PROGRAM = '''
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <mad.h>

int main ()
{
  system("touch conf.madtest");
  return 0;
}
'''


def find_mad(mad_prefix='/usr/local', enable_madtest=1):
  """A rough translation of mad.m4"""

  mad_include_dir = mad_prefix + '/include'
  mad_lib_dir = mad_prefix + '/lib'

  msg_checking('for MAD')

  if enable_madtest:
    execute('rm -f conf.madtest', 0)

    try:
      run_test(MAD_TEST_PROGRAM, flags='-I' + mad_include_dir)
      if not os.path.isfile('conf.madtest'):
        raise RuntimeError('Did not produce output')
      execute('rm conf.madtest', 0)

    except:
      print('test program failed')
      return None

  print('success')

  return {'library_dirs': mad_lib_dir,
          'include_dirs': mad_include_dir}


def write_data(data):
  setup_file = open('setup.cfg', 'w')
  setup_file.write('[build_ext]\n')
  for item in list(data.items()):
    setup_file.write('%s=%s\n' % item)
  setup_file.close()
  print('Wrote setup.cfg file')


def print_help():
  print('''%s
    --prefix      Give the prefix in which MAD was installed.''' % sys.argv[0])
  sys.exit(0)


def parse_args():
  data = {}
  argv = sys.argv
  for pos in range(len(argv)):
    if argv[pos] == '--help':
      print_help()
    if argv[pos] == '--prefix':
      pos = pos + 1
      if len(argv) == pos:
        print('Prefix needs an argument')
        sys.exit(1)
      data['prefix'] = argv[pos]

  return data


def main():
  args = parse_args()
  prefix = args.get('prefix', '/usr/local')

  data = find_mad(mad_prefix=prefix)
  if not data:
    print('Config failure')
    sys.exit(1)
  write_data(data)

if __name__ == '__main__':
  main()



#!/usr/bin/env python

"""Setup script for the MAD module distribution."""

import os
import re
import sys

from distutils.core import setup
from distutils.extension import Extension

VERSION_MAJOR = 0
VERSION_MINOR = 10
PYMAD_VERSION = str(VERSION_MAJOR) + '.' + str(VERSION_MINOR)


DEFINES = [('VERSION_MAJOR', VERSION_MAJOR),
           ('VERSION_MINOR', VERSION_MINOR),
           ('VERSION', '"%s"' % PYMAD_VERSION)]

MADMODULE = Extension(
    name='mad',
    sources=['src/madmodule.c', 'src/pymadfile.c', 'src/xing.c'],
    define_macros=DEFINES,
    libraries=['mad'])

setup(  # Distribution metadata
    name='pymad',
    version=PYMAD_VERSION,
    description='A wrapper for the MAD libraries.',
    author='Jamie Wilkinson',
    author_email='jaq@spacepants.org',
    url='http://spacepants.org/src/pymad/',
    license='GPL',
    ext_modules=[MADMODULE])



#! /usr/bin/python

import glob
import os.path
import sys
import io
import urllib.request
import urllib.parse
import urllib.error

import ao

for p in glob.glob("build/lib.*"):
    sys.path.insert(0, p)

print((sys.path))

import mad

data = io.StringIO(open("/home/jaq/foo.mp3", "r").read())
m = mad.MadFile(data)
print("MadFile returned")
for x in (1, 2):
    pass
print("got here")
